@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: gen_completions.pl,v 1.3 2002/03/14 17:32:06 pajas Exp $
+# $Id: gen_completions.pl,v 2.1 2004/12/02 19:26:40 pajas Exp $
 
 use strict;
 use XML::LibXML;
@@ -17,10 +17,10 @@ EOF
 }
 
 print <<'EOF';
-package XML::XSH::CompletionList;
+package XML::XSH2::CompletionList;
 
 use strict;
-use vars qw(@XSH_COMMANDS);
+use vars qw(@XSH_COMMANDS @XSH_NOXPATH_COMMANDS);
 
 @XSH_COMMANDS=qw(
 EOF
@@ -35,14 +35,15 @@ sub get_name {
 my $parser=XML::LibXML->new();
 $parser->load_ext_dtd(1);
 $parser->validation(1);
-my $doc=$parser->parse_file($ARGV[0]);
+my $dom=$parser->parse_file($ARGV[0]);
 
-my $dom=$doc->getDocumentElement();
+my $doc=$dom->getDocumentElement();
 
 foreach (sort map { get_name($_) }
-	 $dom->findnodes('./rules/rule[@type="command"]'),
-	 $dom->findnodes('./rules/rule[@type="command"]/aliases/alias')) {
+	 $doc->findnodes('./rules/rule[@type="command"]'),
+	 $doc->findnodes('./rules/rule[@type="command"]/aliases/alias')) {
   print "$_\n";
 }
 
 print ");\n\n1;\n";
+
